@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: config.h 92 2004-10-06 10:29:54Z kiza $
+ * $Id: config.h 500 2004-12-08 14:02:44Z kiza $
  * 
  * Copyright 2003 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -69,6 +69,8 @@ struct newsdata {
 	char *title;
 	char *link;
 	char *description;
+	char *hash;
+	int date;
 };
 
 /* Global program keybindings. Loaded from setup:Config() */
@@ -128,7 +130,7 @@ extern struct feed *first_ptr;
 #ifdef LOCALEPATH
 #	define _(String) gettext (String)
 #else
-#	define _(String) (String)s
+#	define _(String) (String)
 # 	define ngettext(Singular, Plural, n) (Plural)
 #endif
 
