@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: conversions.c 286 2004-10-30 12:22:09Z kiza $
+ * $Id: conversions.c 500 2004-12-08 14:02:44Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de> and
  *                     Rene Puls <rpuls@gmx.net>
@@ -31,18 +31,31 @@
 #include <string.h>
 #include <unistd.h>
 #include <errno.h>
-#include <zlib.h>
 #include <libxml/HTMLparser.h>
 #include <langinfo.h>
 
+/* I have no idea what needs to be defined to get strptime() on glibc.
+ * This is stolen from somewhere else and it works for me(tm).
+ * If you know how it's supposed to work, tell me. Manpage says
+ * define _XOPEN_SOURCE for glibc2, but that doesn't work. */
+#define _XOPEN_SOURCE 500		/* Needed for glibc2 strptime(). What's the 500 for? */
+#define __USE_XOPEN
+#include <time.h>
+#undef __USE_XOPEN
+#undef _XOPEN_SOURCE
+
 #include "conversions.h"
 #include "config.h"
 #include "interface.h"
 #include "ui-support.h"
 #include "setup.h"
+#include "md5.h"
+#include "digcalc.h"
 
 extern struct entity *first_entity;
 
+int calcAgeInDays (struct tm * t);
+
 #ifdef STATIC_CONST_ICONV
 char * iconvert (const char * inbuf) {
 #else
@@ -50,7 +63,7 @@ char * iconvert (char * inbuf) {
 #endif
 	iconv_t cd;							/* Iconvs conversion descriptor. */
 	char *outbuf, *outbuf_first;		/* We need two pointers so we do not lose
-	                                       the strings starting position. */
+	                                      the string starting position. */
 	size_t inbytesleft, outbytesleft;
 
 	/* Take a shortcut. */
@@ -505,6 +518,12 @@ void CleanupString (char * string, int tidyness) {
 		len--;
 	}
 	
+	/* Remove trailing spaces. */
+	while ((len > 1) && (string[len-1] == ' ')) {
+		string[len-1] = 0;
+		len--;
+	}
+	
 	len = strlen(string);
 	/* Eat newlines and tabs along the whole string. */
 	if (tidyness == 1) {
@@ -553,3 +572,188 @@ char * Hashify (const char * url) {
 	
 	return hashed_url;
 }
+
+char * genItemHash (char ** hashitems, int items) {
+	int i;
+	unsigned char MD5Digest[16];
+	struct MD5Context MD5Ctx;
+	HASHHEX HexDigest;
+	
+	MD5Init (&MD5Ctx);
+	
+	for (i = 0; i < items; i++) {
+		if (hashitems[i] != NULL)
+			MD5Update (&MD5Ctx, hashitems[i], strlen(hashitems[i]));
+	}
+	MD5Final (MD5Digest, &MD5Ctx);
+	CvtHex (MD5Digest, HexDigest);
+	
+	return strdup(HexDigest);
+}
+
+/* Date conversion */
+/* 2004-11-20T19:45:00+00:00 */
+int ISODateToUnix (char const * const ISODate) {
+	struct tm *t;
+	time_t tt = 0;
+	int time_unix = 0;
+	
+	/* Do not crash with an empty tag */
+	if (ISODate == NULL)
+		return 0;
+	
+	t = malloc(sizeof(struct tm));
+	gmtime_r(&tt, t);
+	
+	/* OpenBSD does not know %F == %Y-%m-%d
+	 * <insert inflamatory comment here> */
+	if (strptime(ISODate, "%Y-%m-%dT%T", t)) {
+#ifdef __CYGWIN__
+		time_unix = mktime(t);
+#else
+		time_unix = timegm(t);
+#endif
+	} else if (strptime(ISODate, "%Y-%m-%d", t)) {
+#ifdef __CYGWIN__
+		time_unix = mktime(t);
+#else
+		time_unix = timegm(t);
+#endif
+	}
+	
+	free (t);
+	return time_unix;
+}
+/* Sat, 20 Nov 2004 21:45:40 +0000 */
+int pubDateToUnix (char const * const pubDate) {
+	char const *start_here;
+	struct tm *t;
+	time_t tt = 0;
+	int time_unix = 0;
+	char *oldlocale;
+	
+	/* Do not crash with an empty Tag */
+	if (pubDate == NULL)
+		return 0;
+	
+	start_here = pubDate;
+	start_here += 5;
+	
+	t = malloc(sizeof(struct tm));
+	gmtime_r(&tt, t);
+	
+	/* Cruft!
+	 * Save old locale so we can parse the stupid pubDate format.
+	 * However strftime is not really more intelligent since there is no
+	 * format string for abbr. month name NOT in the current locale. Grr.
+	 *
+	 * This is also not thread safe!
+	 */
+	oldlocale = strdup(setlocale(LC_TIME, NULL));
+	if (oldlocale) {
+		/* Only reset if setlocale returned something !NULL.
+		 * Will not parse the date correctly in this case, but will also not
+		 * overwrite the user's locale setting.
+		 */
+		setlocale(LC_TIME, "C");
+	}
+	
+	if (strptime(start_here, "%d %b %Y %T", t)) {
+#ifdef __CYGWIN__
+		time_unix = mktime(t);
+#else
+		time_unix = timegm(t);
+#endif
+	}
+	
+	if (oldlocale) {
+		setlocale(LC_TIME, oldlocale);
+		free (oldlocale);
+	}
+	
+	free (t);
+	return time_unix;
+}
+char * unixToPostDateString (int unixDate) {
+	time_t unix_t;
+	struct tm t;
+	char *time_str;
+	int len = 64;
+	char *time_strfstr;
+	int strfstr_len = 32;
+	char tmpstr[32];
+	int age;
+	
+	time_str = malloc(len);
+	time_strfstr = malloc(strfstr_len);
+	
+	unix_t = unixDate;
+	gmtime_r(&unix_t, &t);
+	
+	age = calcAgeInDays(&t);
+	
+	strftime(time_strfstr, strfstr_len, _(", %H:%M"), &t);
+	strcpy(time_str, _("Posted "));
+	len -= strlen(_("Posted "));
+	if (len <= 0)
+		return NULL;
+	
+	if (age == 0) {
+		strncat(time_str, _("today"), len-1);
+		len -= strlen(_("today"));
+		if (len <= 0)
+			return NULL;
+		if (!(!t.tm_hour && !t.tm_min && !t.tm_sec))
+			strncat(time_str, time_strfstr, len-1);
+	} else if (age == 1) {
+		strncat(time_str, _("yesterday"), len-1);
+		len -= strlen(_("yesterday"));
+		if (len <= 0)
+			return NULL;
+		if (!(!t.tm_hour && !t.tm_min && !t.tm_sec))
+			strncat(time_str, time_strfstr, len-1);
+	} else if ((age > 1) && (age < 7)) {
+		snprintf(tmpstr, sizeof(tmpstr), _("%d days ago"), age);
+		strncat(time_str, tmpstr, len-1);
+		len -= strlen(tmpstr);
+		if (len <= 0)
+			return NULL;
+		if (!(!t.tm_hour && !t.tm_min && !t.tm_sec))
+			strncat(time_str, time_strfstr, len-1);
+	} else if (age == 7) {
+		strncat(time_str, _("a week ago"), len-1);
+		len -= strlen(_("a week ago"));
+		if (len <= 0)
+			return NULL;
+		if (!(!t.tm_hour && !t.tm_min && !t.tm_sec))
+			strncat(time_str, time_strfstr, len-1);
+	} else if (age < 0) {
+		strcpy(time_str, _("Not yet posted: "));
+		len = 64 - strlen(_("Not yet posted: "));
+		if (!t.tm_hour && !t.tm_min && !t.tm_sec)
+			strftime(time_strfstr, strfstr_len, _("%x"), &t);
+		else
+			strftime(time_strfstr, strfstr_len, _("%x, %H:%M"), &t);
+		strncat(time_str, time_strfstr, len-1);
+	} else {
+		if (!t.tm_hour && !t.tm_min && !t.tm_sec)
+			strftime(time_strfstr, strfstr_len, _("%x"), &t);
+		else
+			strftime(time_strfstr, strfstr_len, _("%x, %H:%M"), &t);
+		strncat(time_str, time_strfstr, len-1);
+	}
+	free (time_strfstr);
+	
+	return time_str;
+}
+
+int calcAgeInDays (struct tm * t) {
+	time_t unix_t;
+	struct tm current_t;
+	
+	unix_t = time(NULL);
+	gmtime_r(&unix_t, &current_t);
+
+	/* (((current year - passed year) * 365) + current year day) - passed year day */
+	return (((current_t.tm_year - t->tm_year) * 365) + current_t.tm_yday) - t->tm_yday;
+}
