@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: conversions.h 286 2004-10-30 12:22:09Z kiza $
+ * $Id: conversions.h 500 2004-12-08 14:02:44Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de> and
  *                     Rene Puls <rpuls@gmx.net>
@@ -35,5 +35,9 @@ char *base64encode(char const *inbuf, unsigned int inbuf_size);
 char* decodechunked(char * chunked, unsigned int *inputlen);
 void CleanupString (char * string, int tidyness);
 char * Hashify (const char * url);
+char * genItemHash (char ** hashitems, int items);
+int ISODateToUnix (char const * const ISODate);
+int pubDateToUnix (char const * const pubDate);
+char * unixToPostDateString (int unixDate);
 
 #endif
