@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: dialog.c 286 2004-10-30 12:22:09Z kiza $
+ * $Id: dialog.c 500 2004-12-08 14:02:44Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -226,30 +226,10 @@ int UIAddFeed (char * newurl) {
 	} else
 		url = strdup (newurl);
 
-	new_ptr = malloc (sizeof(struct feed));
+	new_ptr = newFeedStruct();
+	
 	/* getnstr does not return newline... says the docs. */
 	new_ptr->feedurl = malloc (strlen(url)+1);
-	new_ptr->feed = NULL;
-	new_ptr->content_length = 0;
-	new_ptr->title = NULL;
-	new_ptr->link = NULL;
-	new_ptr->description = NULL;
-	new_ptr->lastmodified = NULL;
-	new_ptr->lasthttpstatus = 0;
-	new_ptr->content_type = NULL;
-	new_ptr->netio_error = NET_ERR_OK;
-	new_ptr->connectresult = 0;
-	new_ptr->cookies = NULL;
-	new_ptr->authinfo = NULL;
-	new_ptr->servauth = NULL;
-	new_ptr->items = NULL;
-	new_ptr->problem = 0;
-	new_ptr->override = NULL;
-	new_ptr->original = NULL;
-	new_ptr->perfeedfilter = NULL;
-	new_ptr->execurl = 0;
-	new_ptr->smartfeed = 0;
-	new_ptr->feedcategories = NULL;
 	
 	/* Attach to feed pointer chain. */
 	strncpy (new_ptr->feedurl, url, strlen(url)+1);
