@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: digcalc.h 92 2004-10-06 10:29:54Z kiza $
+ * $Id: digcalc.h 500 2004-12-08 14:02:44Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -11,6 +11,9 @@
  * MD5 implementation rather than using RSA's.
  */
 
+#ifndef DIGCALC_H
+#define DIGCALC_H
+
 #define HASHLEN 16
 typedef char HASH[HASHLEN];
 #define HASHHEXLEN 32
@@ -41,3 +44,10 @@ void DigestCalcResponse(
     IN HASHHEX HEntity,       /* H(entity body) if qop="auth-int" */
     OUT HASHHEX Response      /* request-digest or response-digest */
     );
+
+void CvtHex(
+    IN HASH Bin,
+    OUT HASHHEX Hex
+    );
+
+#endif
