@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: interface.c 286 2004-10-30 12:22:09Z kiza $
+ * $Id: interface.c 500 2004-12-08 14:02:44Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -47,6 +47,7 @@
 #include "about.h"
 #include "io-internal.h"
 #include "os-support.h"
+#include "support.h"
 
 extern struct keybindings keybindings;
 extern struct color color;
@@ -87,6 +88,7 @@ void UIDisplayItem (struct newsitem * current_item, struct feed * current_feed,
 	char *converted;				/* Converted from UTF-8 to local charset. */
 	int rewrap;						/* Set to 1 if text needs to be rewrapped. */
 	int forceredraw = 0;
+	char *date_str;
 	
 	
 	/* Activate rewrap. */
@@ -143,6 +145,19 @@ void UIDisplayItem (struct newsitem * current_item, struct feed * current_feed,
 		
 		attroff (WA_BOLD);
 		
+		/* Print publishing date if we have one. */
+		move (LINES-3, 0);
+		clrtoeol();
+		if (current_item->data->date != 0) {
+			date_str = unixToPostDateString(current_item->data->date);
+			if (date_str) {
+				attron(WA_BOLD);
+				mvaddstr(LINES-3, 2, date_str);
+				attroff(WA_BOLD);
+				free (date_str);
+			}
+		}
+		
 		/* Don't print feed titles longer than screenwidth here.
 		   columns is needed to avoid race conditions while resizing the window. */
 		columns = COLS-6;
@@ -1006,7 +1021,7 @@ void UIMainInterface (void) {
 				}
 				
 				if (addfilteritem) {
-					new_ptr = malloc (sizeof(struct feed));
+					new_ptr = newFeedStruct();
 					/* These structs will get leaked!
 					   Yeah, yeah, it is on my todo list...
 					   Though valgrind doesn't report them as leaked. */
@@ -1153,6 +1168,10 @@ void UIMainInterface (void) {
 			UIStatus (tmp, 0, 0);
 		} else {
 			snprintf (tmp, sizeof(tmp), _("Press '%c' for help window."), keybindings.help);
+			if (easterEgg()) {
+				snprintf (tmp, sizeof(tmp), _("Press '%c' for help window. (Press '%c' to play Santa Hunta!)"),
+					keybindings.help, keybindings.about);
+			}
 			UIStatus (tmp, 0, 0);
 		}
 		
@@ -1540,7 +1559,7 @@ void UIMainInterface (void) {
 					first_scr_ptr = first_ptr;
 					highlighted = first_ptr;
 					first_bak = NULL;
-				} else if (highlighted->feedcategories != NULL) {
+				} else if ((highlighted != NULL) && (highlighted->feedcategories != NULL)) {
 					filters[0] = strdup (highlighted->feedcategories->name);
 					filteractivated = 1;
 				}
