@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: io-internal.c 286 2004-10-30 12:22:09Z kiza $
+ * $Id: io-internal.c 500 2004-12-08 14:02:44Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -49,6 +49,36 @@
 
 extern char *browser;
 
+struct feed * newFeedStruct (void) {
+	struct feed *new;
+	
+	new = malloc(sizeof(struct feed));
+	
+	new->feed = NULL;
+	new->content_length = 0;
+	new->title = NULL;
+	new->link = NULL;
+	new->description = NULL;
+	new->lastmodified = NULL;
+	new->lasthttpstatus = 0;
+	new->content_type = NULL;
+	new->netio_error = NET_ERR_OK;
+	new->connectresult = 0;
+	new->cookies = NULL;
+	new->authinfo = NULL;
+	new->servauth = NULL;
+	new->items = NULL;
+	new->problem = 0;
+	new->override = NULL;
+	new->original = NULL;
+	new->perfeedfilter = NULL;
+	new->execurl = 0;
+	new->smartfeed = 0;
+	new->feedcategories = NULL;
+	
+	return new;
+}
+
 void GetHTTPErrorString (char * errorstring, int size, int httpstatus) {
 	switch (httpstatus) {
 		case 400:
@@ -336,6 +366,7 @@ void WriteCache (void) {
 	char file[512];				/* File locations. */
 	char *hashme;				/* Cache file name. */
 	char readstatus[2];
+	char snowdate[32];
 	char syscall[512];
 	FILE *configfile;
 	FILE *cache;
@@ -431,12 +462,12 @@ void WriteCache (void) {
 		if (cache == NULL)
 			MainQuit (_("Writing cache file"), strerror(errno));
 		
-		fputs ("<?xml version=\"1.0\" ?>\n\n<rdf:RDF\n  xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\"\n  xmlns=\"http://purl.org/rss/1.0/\">\n\n", cache);
+		fputs ("<?xml version=\"1.0\" ?>\n\n<rdf:RDF\n  xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\"\n  xmlns=\"http://purl.org/rss/1.0/\"\n  xmlns:snow=\"http://snownews.kcore.de/ns/1.0/\">\n\n", cache);
 		
 		if (cur_ptr->lastmodified != NULL) {
-			fputs ("<lastmodified>", cache);
+			fputs ("<snow:lastmodified>", cache);
 			fputs (cur_ptr->lastmodified, cache);
-			fputs ("</lastmodified>\n", cache);
+			fputs ("</snow:lastmodified>\n", cache);
 		}
 				
 		fputs ("<channel rdf:about=\"", cache);
@@ -495,10 +526,17 @@ void WriteCache (void) {
 				fputs (encoded, cache);
 				free (encoded);
 			}
-			fputs ("</description>\n<readstatus>", cache);
+			fputs ("</description>\n<snow:readstatus>", cache);
 			snprintf (readstatus, sizeof(readstatus), "%d", item->data->readstatus);
 			fputs (readstatus, cache);			
-			fputs ("</readstatus>\n</item>\n\n", cache);
+			fputs ("</snow:readstatus>\n<snow:hash>", cache);
+			if (item->data->hash != NULL) {
+				fputs (item->data->hash, cache);
+			}
+			fputs ("</snow:hash>\n<snow:date>", cache);
+			snprintf (snowdate, sizeof(snowdate), "%d", item->data->date);
+			fputs (snowdate, cache);
+			fputs ("</snow:date>\n</item>\n\n", cache);
 		}
 		
 		fputs ("</rdf:RDF>", cache);
