@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: main.c 286 2004-10-30 12:22:09Z kiza $
+ * $Id: main.c 500 2004-12-08 14:02:44Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -46,6 +46,28 @@
 #include "io-internal.h"
 
 extern struct feed *first_bak;		/* For use with the signal handler. */
+static int const pid_file_create = 1;
+static int const pid_file_delete = 0;
+
+static int last_signal = 0;
+
+void modifyPIDFile (int action) {
+	char pid_path[512];
+	FILE *file;
+	
+	snprintf(pid_path, sizeof(pid_path), "%s/.snownews/pid", getenv("HOME"));	
+	if (action == pid_file_create) {
+		file = fopen(pid_path, "w");
+		if (file == NULL) {
+			printf("Unable to write PID file %s!", pid_path);
+			return;
+		}
+		fprintf(file, "%d", getpid());
+		fclose(file);
+	} else {
+		unlink(pid_path);
+	}
+}
 
 /* Deinit ncurses and quit. */
 void MainQuit (char * func, char * error) {
@@ -56,7 +78,12 @@ void MainQuit (char * func, char * error) {
 	clear();
 	refresh();
 	endwin();		/* Make sure no ncurses function is called after this point! */
+	
+	modifyPIDFile(pid_file_delete);
 
+	if (last_signal)
+		printf ("Exiting via signal %d.\n", last_signal);
+	
 	if (error == NULL) {		
 		printf (_("Bye.\n\n"));
 		
@@ -70,7 +97,9 @@ void MainQuit (char * func, char * error) {
 		printf (_("Aborting program execution!\nAn internal error occured. Snownews has quit, no changes has been saved!\n"));
 		printf (_("This shouldn't happen, please submit a bugreport to kiza@kcore.de, tell me what you where doing and include the output below in your mail.\n"));
 		printf ("----\n");
-		/* Please don't localize! I don't want to receive Japanese error messages. Thanks. :) */
+		/* Please don't localize! I don't want to receive Japanese error messages.
+		 * Thanks. :)
+		 */
 		printf ("While executing: %s\n", func);
 		printf ("Error as reported by the system: %s\n\n", error);
 		exit(1);
@@ -79,13 +108,13 @@ void MainQuit (char * func, char * error) {
 
 /* Signal handler function. */
 void MainSignalHandler (int sig) {
-	if (sig == SIGINT) {
-		/* If there is a first_bak!=NULL a filter is set. Reset first_ptr
-		   so the correct list gets written on the disk when exisiting via SIGINT. */
-		if (first_bak != NULL)
-			first_ptr = first_bak;
-		MainQuit(NULL, NULL);
-	}
+	last_signal = sig;
+	
+	/* If there is a first_bak!=NULL a filter is set. Reset first_ptr
+	   so the correct list gets written on the disk when exisiting via SIGINT. */
+	if (first_bak != NULL)
+		first_ptr = first_bak;
+	MainQuit(NULL, NULL);
 }
 
 /* Automatic child reaper. */
@@ -137,9 +166,10 @@ int main (int argc, char *argv[]) {
 		}
 	}
 	
-	
-	/* Install SIGINT signal handler. */
+	/* Get fragged gracefully. */
+	signal (SIGHUP, MainSignalHandler);
 	signal (SIGINT, MainSignalHandler);
+	signal (SIGTERM, MainSignalHandler);
 	
 	/* Un-broken pipify */
 	signal (SIGPIPE, SIG_IGN);
@@ -151,6 +181,9 @@ int main (int argc, char *argv[]) {
 	
 	/* Check if configfiles exist and create/read them. */
 	numfeeds = Config();
+	
+	/* Create PID file. */
+	modifyPIDFile(pid_file_create);
 		
 	LoadAllFeeds (numfeeds);
 
