@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: netio.c 286 2004-10-30 12:22:09Z kiza $
+ * $Id: netio.c 500 2004-12-08 14:02:44Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -40,7 +40,6 @@
 #include <string.h>
 #include <errno.h>
 #include <unistd.h>
-//#include <fcntl.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
@@ -74,7 +73,7 @@ extern char *useragent;
  * Returns
  *
  *	0	Socket is ready
- *	-1	Error occured (netio_error is set)
+ *	-1	Error occurred (netio_error is set)
  */
 int NetPoll (struct feed * cur_ptr, int * my_socket, int rw) {
 	fd_set rfdsr;
@@ -339,7 +338,7 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 		/* Request URL from HTTP server. */
 		if (cur_ptr->lastmodified != NULL) {
 			fprintf(stream,
-					"GET %s HTTP/1.0\r\nAccept-Encoding: gzip\r\nUser-Agent: %s\r\nConnection: close\r\nHost: %s\r\nIf-Modified-Since: %s\r\n%s%s\r\n",
+					"GET %s HTTP/1.0\r\nAccept-Encoding: gzip\r\nAccept: application/rdf+xml,application/rss+xml,application/xml,text/xml;q=0.9,*/*;q=0.1\r\nUser-Agent: %s\r\nConnection: close\r\nHost: %s\r\nIf-Modified-Since: %s\r\n%s%s\r\n",
 					url,
 					useragent,
 					host,
@@ -348,7 +347,7 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 					(cur_ptr->cookies ? cur_ptr->cookies : ""));
 		} else {
 			fprintf(stream,
-					"GET %s HTTP/1.0\r\nAccept-Encoding: gzip\r\nUser-Agent: %s\r\nConnection: close\r\nHost: %s\r\n%s%s\r\n",
+					"GET %s HTTP/1.0\r\nAccept-Encoding: gzip\r\nAccept: application/rdf+xml,application/rss+xml,application/xml,text/xml;q=0.9,*/*;q=0.1\r\nUser-Agent: %s\r\nConnection: close\r\nHost: %s\r\n%s%s\r\n",
 					url,
 					useragent,
 					host,
@@ -360,7 +359,7 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 		/* Request URL from HTTP server. */
 		if (cur_ptr->lastmodified != NULL) {
 			fprintf(stream,
-					"GET http://%s%s HTTP/1.0\r\nAccept-Encoding: gzip\r\nUser-Agent: %s\r\nConnection: close\r\nHost: %s\r\nIf-Modified-Since: %s\r\n%s%s\r\n",
+					"GET http://%s%s HTTP/1.0\r\nAccept-Encoding: gzip\r\nAccept: application/rdf+xml,application/rss+xml,application/xml,text/xml;q=0.9,*/*;q=0.1\r\nUser-Agent: %s\r\nConnection: close\r\nHost: %s\r\nIf-Modified-Since: %s\r\n%s%s\r\n",
 					host,
 					url,
 					useragent,
@@ -370,7 +369,7 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 					(cur_ptr->cookies ? cur_ptr->cookies : ""));
 		} else {
 			fprintf(stream,
-					"GET http://%s%s HTTP/1.0\r\nAccept-Encoding: gzip\r\nUser-Agent: %s\r\nConnection: close\r\nHost: %s\r\n%s%s\r\n",
+					"GET http://%s%s HTTP/1.0\r\nAccept-Encoding: gzip\r\nAccept: application/rdf+xml,application/rss+xml,application/xml,text/xml;q=0.9,*/*;q=0.1\r\nUser-Agent: %s\r\nConnection: close\r\nHost: %s\r\n%s%s\r\n",
 					host,
 					url,
 					useragent,
@@ -432,6 +431,9 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 				/* Received good status from server, clear problem field. */
 				cur_ptr->netio_error = NET_ERR_OK;
 				cur_ptr->problem = 0;
+				
+				/* Avoid looping on 20x status codes. */
+				handled = 1;
 				break;
 			case 300:	/* Multiple choice and everything 300 not handled is fatal. */
 				cur_ptr->netio_error = NET_ERR_HTTP_NON_200;
@@ -524,7 +526,7 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 								return NULL;
 							}
 							if (!suppressoutput) {
-								UIStatus (_("URL points to permanent redirect, updating with new location..."), 2, 0);
+								UIStatus (_("URL points to permanent redirect, updating with new location..."), 1, 0);
 								printlog (cur_ptr, _("URL points to permanent redirect, updating with new location..."));
 							}
 							free (cur_ptr->feedurl);
@@ -823,12 +825,6 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 	/* If inflate==1 we need to decompress the content.. */
 	if (inflate == 1) {
 		/* gzipinflate */
-		/*inflatedbody = gzip_uncompress (body, length, &cur_ptr->content_length);
-		if (inflatedbody == NULL) {
-			free (body);
-			cur_ptr->netio_error = NET_ERR_GZIP_ERR;
-			return NULL;
-		}*/
 		if (jg_gzip_uncompress (body, length, (void **)&inflatedbody, &cur_ptr->content_length) != 0) {
 			free (body);
 			cur_ptr->netio_error = NET_ERR_GZIP_ERR;
