@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: setup.c 92 2004-10-06 10:29:54Z kiza $
+ * $Id: setup.c 500 2004-12-08 14:02:44Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -42,6 +42,7 @@
 #include "version.h"
 #include "main.h"
 #include "setup.h"
+#include "io-internal.h"
 
 struct feed *first_ptr = NULL;
 struct entity *first_entity = NULL;
@@ -610,29 +611,8 @@ int Config (void) {
 				break;
 			
 			numfeeds++;
-			new_ptr = malloc (sizeof(struct feed));
-			
-			new_ptr->feed = NULL;
-			new_ptr->content_length = 0;
-			new_ptr->title = NULL;
-			new_ptr->link = NULL;
-			new_ptr->description = NULL;
-			new_ptr->lastmodified = NULL;
-			new_ptr->lasthttpstatus = 0;
-			new_ptr->content_type = NULL;
-			new_ptr->netio_error = NET_ERR_OK;
-			new_ptr->connectresult = 0;
-			new_ptr->cookies = NULL;
-			new_ptr->authinfo = NULL;
-			new_ptr->servauth = NULL;
-			new_ptr->items = NULL;
-			new_ptr->problem = 0;
-			new_ptr->override = NULL;
-			new_ptr->original = NULL;
-			new_ptr->perfeedfilter = NULL;
-			new_ptr->execurl = 0;
-			new_ptr->smartfeed = 0;
-			new_ptr->feedcategories = NULL;
+			new_ptr = newFeedStruct();
+
 			/* Reset to NULL on every loop run! */
 			categories = NULL;
 			
