@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: ui-support.c 92 2004-10-06 10:29:54Z kiza $
+ * $Id: ui-support.c 500 2004-12-08 14:02:44Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -34,6 +34,7 @@
 #include "config.h"
 #include "version.h"
 #include "ui-support.h"
+#include "io-internal.h"
 
 extern struct color color;
 extern char *browser;
@@ -83,7 +84,7 @@ void UIStatus (char * text, int delay, int warning) {
 void SwapPointers (struct feed * one, struct feed * two) {
 	struct feed *tmp;
 
-	tmp = malloc (sizeof(struct feed));
+	tmp = newFeedStruct();
 	
 	tmp->feedurl = one->feedurl;
 	tmp->feed = one->feed;
