@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: xmlparse.c 181 2004-10-20 14:10:45Z kiza $
+ * $Id: xmlparse.c 500 2004-12-08 14:02:44Z kiza $
  * 
  * Copyright 2003-2004 Rene Puls <rpuls@gmx.net> and
  *                     Oliver Feiler <kiza@kcore.de>
@@ -39,6 +39,9 @@ int saverestore;
 struct newsitem *copy;
 struct newsitem *firstcopy;
 
+static xmlChar const * const dcNs = "http://purl.org/dc/elements/1.1/";
+static xmlChar const * const snowNs = "http://snownews.kcore.de/ns/1.0/";
+
 /* Wird whrend des Parsens aufgerufen, falls wir auf ein <channel> Element
    treffen. Die Funktion gibt ein neues Struct fr den Newsfeed zurck. */
 
@@ -56,12 +59,14 @@ void parse_rdf10_channel(struct feed * feed, xmlDocPtr doc, xmlNodePtr node) {
 			free (feed->items->prev_ptr->data->title);
 			free (feed->items->prev_ptr->data->link);
 			free (feed->items->prev_ptr->data->description);
+			free (feed->items->prev_ptr->data->hash);
 			free (feed->items->prev_ptr->data);
 			free (feed->items->prev_ptr);
 		}
 		free (feed->items->data->title);
 		free (feed->items->data->link);
 		free (feed->items->data->description);
+		free (feed->items->data->hash);
 		free (feed->items->data);
 		free (feed->items);
 	}
@@ -120,12 +125,14 @@ void parse_rdf20_channel(struct feed * feed, xmlDocPtr doc, xmlNodePtr node)
 			free (feed->items->prev_ptr->data->title);
 			free (feed->items->prev_ptr->data->link);
 			free (feed->items->prev_ptr->data->description);
+			free (feed->items->prev_ptr->data->hash);
 			free (feed->items->prev_ptr->data);
 			free (feed->items->prev_ptr);
 		}
 		free (feed->items->data->title);
 		free (feed->items->data->link);
 		free (feed->items->data->description);
+		free (feed->items->data->hash);
 		free (feed->items->data);
 		free (feed->items);
 	}
@@ -179,7 +186,9 @@ void parse_rdf10_item(struct feed *feed, xmlDocPtr doc, xmlNodePtr node)
 {
 	xmlNodePtr cur;
 	xmlChar *readstatusstring;
-
+	char **hashitems = NULL;
+	char *guid = NULL;
+	char *date_str = NULL;
 	struct newsitem *item;
 	struct newsitem *current;
 	
@@ -190,14 +199,18 @@ void parse_rdf10_item(struct feed *feed, xmlDocPtr doc, xmlNodePtr node)
 	item->data->title = NULL;
 	item->data->link = NULL;
 	item->data->description = NULL;
+	item->data->hash = NULL;
 	item->data->readstatus = 0;
 	item->data->parent = feed;
-		
+	item->data->date = 0;
+	
 	/* Alle Tags im <item> Tag durchgehen und die Informationen extrahieren.
 	   Selbe Vorgehensweise wie in der parse_channel() Funktion */
 	for (cur = node; cur != NULL; cur = cur->next) {
 		if (cur->type != XML_ELEMENT_NODE)
 			continue;
+/* Basic RSS */
+/* Title */
 		if (xmlStrcmp(cur->name, "title") == 0) {
 			item->data->title = xmlNodeListGetString(doc, cur->children, 1);
 			CleanupString (item->data->title, 1);
@@ -208,13 +221,9 @@ void parse_rdf10_item(struct feed *feed, xmlDocPtr doc, xmlNodePtr node)
 						item->data->title[strlen(item->data->title)-1] = '\0';
 				}
 			}
-		}
-		else if (xmlStrcmp(cur->name, "link") == 0) {
+/* link */
+		} else if (xmlStrcmp(cur->name, "link") == 0) {
 			item->data->link = xmlNodeListGetString(doc, cur->children, 1);
-			if (item->data->link == NULL) {
-				if (xmlStrcmp(cur->name, "guid") == 0)
-					item->data->link = xmlNodeListGetString(doc, cur->children, 1);
-			}
 			/* Remove trailing newline */
 			if (item->data->link != NULL) {
 				if (strlen(item->data->link) > 1) {
@@ -222,35 +231,75 @@ void parse_rdf10_item(struct feed *feed, xmlDocPtr doc, xmlNodePtr node)
 						item->data->link[strlen(item->data->link)-1] = '\0';
 				}
 			}
-		}
-		else if (xmlStrcmp(cur->name, "description") == 0) {
+/* Description */
+		} else if (xmlStrcmp(cur->name, "description") == 0) {
 			item->data->description = xmlNodeListGetString(doc, cur->children, 1);
 			CleanupString (item->data->description, 0);
-		}
-		else if (xmlStrcmp(cur->name, "readstatus") == 0) {
+/* Userland extensions (No namespace!)*/
+/* guid */
+		} else if (xmlStrcmp(cur->name, "guid") == 0) {
+			guid = xmlNodeListGetString(doc, cur->children, 1);
+/* pubDate */
+		} else if (xmlStrcmp(cur->name, "pubDate") == 0) {
+			date_str = xmlNodeListGetString(doc, cur->children, 1);
+			item->data->date = pubDateToUnix(date_str);
+			xmlFree (date_str);
+/* Dublin Core */
+/* dc:date */
+		} else if (cur->ns &&
+		           (xmlStrcmp(cur->ns->href, dcNs) == 0) && 
+		           (xmlStrcmp(cur->name, "date") == 0)) {
+		    date_str = xmlNodeListGetString(doc, cur->children, 1);
+			item->data->date = ISODateToUnix(date_str);
+			xmlFree (date_str);
+/* Internal usage */
+/* Obsolete/backware compat/migration code */
+		} else if (xmlStrcmp(cur->name, "readstatus") == 0) {
 			/* Will cause memory leak otherwise, xmlNodeListGetString must be freed. */
 			readstatusstring = xmlNodeListGetString(doc, cur->children, 1);
 			item->data->readstatus = atoi (readstatusstring);
 			xmlFree (readstatusstring);
+/* Using snow namespace */
+		} else if (cur->ns && (xmlStrcmp(cur->ns->href, snowNs) == 0) &&
+		           (xmlStrcmp(cur->name, "readstatus") == 0)) {
+			readstatusstring = xmlNodeListGetString(doc, cur->children, 1);
+			item->data->readstatus = atoi (readstatusstring);
+			xmlFree (readstatusstring);
+		} else if (cur->ns && (xmlStrcmp(cur->ns->href, snowNs) == 0) &&
+		           (xmlStrcmp(cur->name, "hash") == 0)) {
+			item->data->hash = xmlNodeListGetString(doc, cur->children, 1);
+		} else if (cur->ns && (xmlStrcmp(cur->ns->href, snowNs) == 0) &&
+		           (xmlStrcmp(cur->name, "date") == 0)) {
+			date_str = xmlNodeListGetString(doc, cur->children, 1);
+			item->data->date = strtoll(date_str, NULL, 10);
+			xmlFree (date_str);
 		}
 	}
 	
+	/* If we have loaded the hash from disk cache, don't regenerate it.
+	   <guid> is not saved in the cache, thus we would generate a different
+	   hash than the one from the live feed. */
+	if (item->data->hash == NULL) {
+		hashitems = malloc (sizeof(char *) * 4);
+		hashitems[0] = item->data->title;
+		hashitems[1] = item->data->link;
+		hashitems[2] = guid;
+		hashitems[3] = NULL;
+		item->data->hash = genItemHash (hashitems, 3);
+		xmlFree (guid);
+		free (hashitems);
+	}
+	
 	/* If saverestore == 1, restore readstatus. */
 	if (saverestore == 1) {
 		for (current = firstcopy; current != NULL; current = current->next_ptr) {
-			if ((current->data->link != NULL) && (item->data->link != NULL)) {
-				if ((current->data->title != NULL) && (item->data->title != NULL)) {
-					if ((strcmp(item->data->link, current->data->link) == 0) &&
-						(strcmp(item->data->title, current->data->title) == 0))
-						item->data->readstatus = current->data->readstatus;
-				} else {
-					if (strcmp(item->data->link, current->data->link) == 0)
-						item->data->readstatus = current->data->readstatus;
-				}
+			if (strcmp(item->data->hash, current->data->hash) == 0) {
+				item->data->readstatus = current->data->readstatus;
+				break;
 			}
 		}
 	}
-
+	
 	item->next_ptr = NULL;
 	if (feed->items == NULL) {
 		item->prev_ptr = NULL;
@@ -289,11 +338,10 @@ int DeXML (struct feed * cur_ptr) {
 			copy->data->title = NULL;
 			copy->data->link = NULL;
 			copy->data->description = NULL;
+			copy->data->hash = NULL;
 			copy->data->readstatus = cur_item->data->readstatus;
-			if (cur_item->data->link != NULL)
-				copy->data->link = strdup (cur_item->data->link);
-			if (cur_item->data->title != NULL)
-				copy->data->title = strdup (cur_item->data->title);
+			if (cur_item->data->hash != NULL)
+				copy->data->hash = strdup (cur_item->data->hash);
 			
 			copy->next_ptr = NULL;
 			if (firstcopy == NULL) {
@@ -342,7 +390,8 @@ int DeXML (struct feed * cur_ptr) {
 			if (xmlStrcmp(cur->name, "item") == 0)
 				parse_rdf10_item(cur_ptr, doc, cur->children);
 			/* Last-Modified is only used when reading from internal feeds (disk cache). */
-			if (xmlStrcmp(cur->name, "lastmodified") == 0)
+			if (cur->ns && (xmlStrcmp(cur->ns->href, snowNs) == 0) &&
+				(xmlStrcmp(cur->name, "lastmodified") == 0))
 				cur_ptr->lastmodified = xmlNodeListGetString(doc, cur->children, 1);
 		}
 	} else if (xmlStrcmp(cur->name, "rss") == 0) {
@@ -363,13 +412,11 @@ int DeXML (struct feed * cur_ptr) {
 		/* free struct newsitem *copy. */
 		while (firstcopy->next_ptr != NULL) {
 			firstcopy = firstcopy->next_ptr;
-			free (firstcopy->prev_ptr->data->link);
-			free (firstcopy->prev_ptr->data->title);
+			free (firstcopy->prev_ptr->data->hash);
 			free (firstcopy->prev_ptr->data);
 			free (firstcopy->prev_ptr);
 		}
-		free (firstcopy->data->link);
-		free (firstcopy->data->title);
+		free (firstcopy->data->hash);
 		free (firstcopy->data);
 		free (firstcopy);
 	}
